@@ -45,6 +45,7 @@ OC.L10N.register(
     "Show all teams" : "顯示所有團隊",
     "Collapse teams" : "折疊團隊",
     "This group already exists" : "該群組已存在",
+    "An error occurred while creating the group" : "建立群組時發生錯誤",
     "This team already exists" : "此團隊已存在",
     "An error happened during the creation of the team" : "建立團隊時發生錯誤",
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
@@ -63,7 +64,6 @@ OC.L10N.register(
     "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
     "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
     "_%n group_::_%n groups_" : ["%n 個群組"],
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
     "Share with users or groups" : "與用戶或群組分享",
     "Share with users" : "與用戶分享",
     "No users or groups" : "沒有用戶或群組",
@@ -119,13 +119,13 @@ OC.L10N.register(
     "Crop contact photo" : "裁剪聯絡人照片",
     "Upload a new picture" : "上傳一張新的圖片",
     "Choose from Files" : "從檔案選取",
-    "Get from " : "取自",
     "Download picture" : "下載圖片",
     "Delete picture" : "刪除圖片",
     "Please select a valid format" : "請選擇有效的格式",
     "Invalid image" : "圖像無效",
     "Error cropping picture" : "裁剪圖片時出錯",
     "Pick an avatar" : "選擇一個虛擬化身大頭照",
+    "Pick" : "挑選",
     "Error while processing the picture." : "處理相片時錯誤。",
     "Avatar downloaded from social network" : "從社群網路下載虛擬化身大頭照",
     "Avatar already up to date" : "虛擬化身大頭照已是最新",
@@ -209,11 +209,6 @@ OC.L10N.register(
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
     "Close" : "關閉",
-    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
-    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
-    "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
-    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在導入 %n 個聯絡人至 {addressbook}"],
-    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成導入 %n 個聯絡人至 {addressbook}"],
     "Import" : "導入",
     "Are you sure you want to import this contact file?" : "您確定您想要匯入此聯絡人檔案嗎？",
     "Could not copy" : "無法複製",
@@ -273,8 +268,10 @@ OC.L10N.register(
     "Postal code" : "郵遞區號",
     "Country" : "國家",
     "Birthday" : "生日",
+    "Place of birth" : "出生地點 :",
     "Anniversary" : "週年",
     "Date of death" : "卒日",
+    "Place of death" : "去世地點",
     "Instant messaging" : "即時通訊",
     "Phone" : "電話",
     "Mobile" : "手提電話",
@@ -287,7 +284,7 @@ OC.L10N.register(
     "Voice" : "音頻",
     "Car" : "車子",
     "Work pager" : "傳呼機（業務）",
-    "Manager" : "上司",
+    "Line manager" : "生產線經理",
     "Social network" : "社交網絡",
     "Relationship to you" : "與您的關係",
     "Spouse" : "配偶",
@@ -315,6 +312,8 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
-    "Unable to delete contact" : "無法刪除聯絡人"
+    "Unable to delete contact" : "無法刪除聯絡人",
+    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "會員資格必須由版主確認/接受（需要開放）",
+    "Manager" : "經理"
 },
 "nplurals=1; plural=0;");
